# --Description: Create a pitch map on a Pitch AISAC Graph

import cri.atomcraft.project as acproject
import cri.atomcraft.debug as acdebug

def intervals_to_cents(intervals):
    cents_values = [sum(intervals[:i]) * 100 for i in range(len(intervals) + 1)]
    cents_neg_values = [value - 1200 for value in cents_values[:-1]]
    return cents_neg_values + cents_values

# List of scale's intervals in semitones
scale_intervals = {
	"augmented": [3, 1, 3, 1, 3, 1],
	"chromatic": [1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1],
	"dorian": [2, 1, 2, 2, 2, 1, 2],
	"major": [2, 2, 1, 2, 2, 2, 1],
	"minor": [2, 1, 2, 2, 1, 2, 2],
	"mixolydian": [2, 2, 1, 2, 2, 1, 2],
	"pentatonic major": [2, 2, 3, 2, 3],
	"whole-tone": [2, 2, 2, 2, 2, 2]
}

# Create the Musical scale, i.e. step points on the graph
chosen_scale = "dorian"
step_values = intervals_to_cents(scale_intervals[chosen_scale])

#----------------------------------------------------------------------

# Get selected AISAC:
selected_aisac = acproject.get_selected_objects("Aisac")["data"]
if not selected_aisac:
	acdebug.warning("No AISAC selected. Please select an AISAC.")
	sys.exit()

aisac_name = acproject.get_value(selected_aisac[0], "Name")["data"]

# Get the pitch graph of the selected AISAC:
get_pitch_graph = acproject.get_aisac_graph(selected_aisac[0], "Pitch")["data"]
if not get_pitch_graph:
	acdebug.warning("This AISAC doesn't have a Pitch graph. Please select an AISAC with a Pitch graph")
	sys.exit()

# Get all the points of the pitch graph:
get_graph_points = acproject.find_objects(get_pitch_graph, "AisacPoint")["data"]

# Delete all the points of the pitch graph:
for point in get_graph_points:
	acproject.delete_object(point)

# Create step points on the graph
for i, value in enumerate(step_values):
	control_value_start = i / (len(step_values))  # Calculate step start point
	control_value_end = (i + 1) / (len(step_values)) - 0.001  # Calculate step end point

	# Create start point
	graph_point_start = acproject.create_aisac_point(get_pitch_graph, control_value_start, value)["data"]

	# Create end point
	graph_point_end = acproject.create_aisac_point(get_pitch_graph, control_value_end, value)["data"]

	# Set the curve type for each point
	acproject.set_value(graph_point_start, "CurveType", "Linear")
	acproject.set_value(graph_point_end, "CurveType", "Linear")

	acdebug.log(f"[{aisac_name}, Pitch graph]: step created at {value} cent")

acdebug.log(f"Pitch graph of {aisac_name} was changed to {chosen_scale} scale.")